use std::path::PathBuf;

use clap::builder::ArgAction::Count;
use clap::Parser;

#[derive(Debug, Parser)]
#[clap(author, version, about)]
pub struct Cli {
    #[clap(
        short,
        action(Count),
        help = "Log level to use, defaults to warning (0) up to trace (3+)."
    )]
    pub verbosity: u8,

    #[clap(
        long,
        action,
        env = "EVALUATION_SYSTEM_CONFIG_DIR",
        help = concat!("Directory with freva config files. If not set, defaults to an OS specific default",
            " e.g. on Linux ~/.config/freva")
    )]
    pub config_dir: Option<PathBuf>,

    #[clap(flatten)]
    pub opts: IngestOpts,
}

#[derive(Debug, Parser)]
pub struct IngestOpts {
    #[clap(
        long,
        action,
        help = concat!("Directory to ingest. If not present, all configured datasets are ingested.",
            " Can be set to a directory within a dataset to only import data within that directory using the ",
            "enclosing dataset for its configuration.")
    )]
    pub data_dir: Option<PathBuf>,

    #[clap(
        long,
        action,
        help = "Size of batches to send to solr",
        default_value = "1000"
    )]
    pub batch_size: usize,
}
